
    import * as React from 'react';

    import { IconType } from '../types';

    type SiActigraphProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#3A4259';

    const SiActigraph: IconType = React.forwardRef<SVGSVGElement, SiActigraphProps>(function SiActigraph({title = 'ActiGraph', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M10.18899 0 .8597 24h4.15078L12 4.97502h.0304L18.9587 24h4.1816L14.18736.91564C13.97372.36626 13.44452 0 12.85444 0ZM12 13.71434a2.47223 2.47223 0 0 0-2.4723 2.47211A2.47223 2.47223 0 0 0 12 18.65876a2.47223 2.47223 0 0 0 2.47211-2.4723 2.47223 2.47223 0 0 0-2.4721-2.47212z' />
        </svg>
      );
    });

    export { SiActigraph as default, defaultColor };
  