
    import * as React from 'react';

    import { IconType } from '../types';

    type SiBackstageCastingProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#000000';

    const SiBackstageCasting: IconType = React.forwardRef<SVGSVGElement, SiBackstageCastingProps>(function SiBackstageCasting({title = 'Backstage', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M10.2 0v.056a5.997 5.997 0 0 1 0 11.886v.113a5.997 5.997 0 0 1 0 11.886v.056h12.552V0ZM1.248 0v24H9.54V0Z' />
        </svg>
      );
    });

    export { SiBackstageCasting as default, defaultColor };
  