
    import * as React from 'react';

    import { IconType } from '../types';

    type SiCobaltProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#FFFFFF';

    const SiCobalt: IconType = React.forwardRef<SVGSVGElement, SiCobaltProps>(function SiCobalt({title = 'cobalt', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M0 4.363v2.778l9.475 5.152L0 16.859v2.778l12.857-6.418V11.49zm11.143 0v2.778l9.474 5.152-9.474 4.566v2.778L24 13.219V11.49z' />
        </svg>
      );
    });

    export { SiCobalt as default, defaultColor };
  