
    import * as React from 'react';

    import { IconType } from '../types';

    type SiInquirerProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#F0DB4F';

    const SiInquirer: IconType = React.forwardRef<SVGSVGElement, SiInquirerProps>(function SiInquirer({title = 'Inquirer', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M8.132 7.14v-.99h.992v-.992h5.752v.992h.793v.991h.992v2.777h-.992v.992h-.793v.992h-.992v.992h-.991v2.975h-1.786V12.1h.992v-.992h.992v-.991h.992v-.992h.991v-1.19h-.991v-.992H9.917v.992h-.991v1.983H7.14V7.14Zm-2.578-.198H1.587v10.116h3.967v1.785H0V5.157h5.554zm12.892 0h3.967v10.116h-3.967v1.785H24V5.157h-5.554zm-7.339 10.116h1.786v1.785h-1.786z' />
        </svg>
      );
    });

    export { SiInquirer as default, defaultColor };
  