
    import * as React from 'react';

    import { IconType } from '../types';

    type SiInvidiousProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#00B6F0';

    const SiInvidious: IconType = React.forwardRef<SVGSVGElement, SiInvidiousProps>(function SiInvidious({title = 'Invidious', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M12 0A12 12 0 0 0 0 12a12 12 0 0 0 12 12 12 12 0 0 0 12-12A12 12 0 0 0 12 0zm0 .742A11.257 11.257 0 0 1 23.258 12 11.257 11.257 0 0 1 12 23.258 11.257 11.257 0 0 1 .742 12 11.257 11.257 0 0 1 12 .742zm-.66 4.375a.776.776 0 0 0-.777.778.776.776 0 0 0 .777.775.776.776 0 0 0 .775-.775.776.776 0 0 0-.775-.778zm.035 2.266-.523 1.853-2.75 9.291h-.713v.373h1.974v-.373h-.875l2.606-8.806 4.6 9.174h1.429L11.375 7.383z' />
        </svg>
      );
    });

    export { SiInvidious as default, defaultColor };
  