
    import * as React from 'react';

    import { IconType } from '../types';

    type SiMetagerProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#F47216';

    const SiMetager: IconType = React.forwardRef<SVGSVGElement, SiMetagerProps>(function SiMetager({title = 'MetaGer', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M1.563 0v6.92h2.083c.818 0 1.227-.434 1.227-1.289V3.264h10.391c3.035 0 4.552 1.613 4.552 4.736v2.575H4.873v1.562c0 .851-.412 1.288-1.227 1.288H.827v4.23C.827 21.885 2.942 24 7.218 24h8.46c4.965 0 7.494-2.575 7.494-7.678V7.678C23.172 2.575 20.643 0 15.678 0zm8.706 13.425h2.246c1.513 0 2.089.777 2.089 2.226v3.389c0 1.15-.577 1.747-1.705 1.747h-1.16c-.976 0-1.47-.578-1.47-1.726v-5.636' />
        </svg>
      );
    });

    export { SiMetager as default, defaultColor };
  