
    import * as React from 'react';

    import { IconType } from '../types';

    type SiNederlandsespoorwegenProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#003082';

    const SiNederlandsespoorwegen: IconType = React.forwardRef<SVGSVGElement, SiNederlandsespoorwegenProps>(function SiNederlandsespoorwegen({title = 'Nederlandse Spoorwegen', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M10.494 11.812a2.602 2.602 0 0 0-1.835-.751H3.576L5.46 9.184h4.753a.757.757 0 0 1 .516.234l2.777 2.77a2.602 2.602 0 0 0 1.835.75h5.084l-1.884 1.878h-4.752a.757.757 0 0 1-.516-.235zm1.459 4.083a2.863 2.863 0 0 0 1.835.798h5.506L24 12l-4.706-4.694H16.66l3.764 3.755h-5.082a.99.99 0 0 1-.516-.188l-2.778-2.769a2.863 2.863 0 0 0-1.835-.798H4.706L0 12l4.706 4.693H7.34L3.577 12.94h5.082a.99.99 0 0 1 .516.187z' />
        </svg>
      );
    });

    export { SiNederlandsespoorwegen as default, defaultColor };
  