
    import * as React from 'react';

    import { IconType } from '../types';

    type SiNetimProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#FE8427';

    const SiNetim: IconType = React.forwardRef<SVGSVGElement, SiNetimProps>(function SiNetim({title = 'Netim', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M23.305 11.95c-1.014-1.134-2.772-1.242-3.927-.248l-.67.577a2.48 2.48 0 0 1 1.274 2.309 2.493 2.493 0 0 1-2.403 2.35 2.488 2.488 0 0 1-2.564-2.484c.067-1.745 1.41-2.484 2.517-2.484l-2.745-6.504c-.59-1.396-2.215-2.054-3.631-1.477-.296.128-1.101.463-1.55 1.484l-2.149 4.994L5.35 5.486C4.765 4.09 3.134 3.432 1.718 4.009.295 4.586-.376 6.184.214 7.574l4.632 10.96c.59 1.397 2.215 2.055 3.631 1.477.437-.194 1.108-.53 1.55-1.483l2.149-4.994 2.108 4.987a2.756 2.756 0 0 0 1.644 1.53 2.83 2.83 0 0 0 2.806-.51l4.33-3.738a2.7 2.7 0 0 0 .241-3.853z' />
        </svg>
      );
    });

    export { SiNetim as default, defaultColor };
  