
    import * as React from 'react';

    import { IconType } from '../types';

    type SiPremidProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#7289DA';

    const SiPremid: IconType = React.forwardRef<SVGSVGElement, SiPremidProps>(function SiPremid({title = 'PreMiD', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M22.46 4.075c.85 0 1.54.69 1.54 1.54v12.77c0 .85-.69 1.54-1.54 1.54H1.54c-.85 0-1.54-.69-1.54-1.54V5.615c0-.85.69-1.54 1.54-1.54ZM3.442 8.485c-.4 0-.725.323-.725.724v5.673a.725.725 0 0 0 1.08.631l5.043-2.836a.725.725 0 0 0 0-1.263L3.797 8.577a.7.7 0 0 0-.355-.093m17.162 5.372h-7.698a.68.68 0 1 0 0 1.358h7.698a.68.68 0 1 0 0-1.358m0-2.446h-7.698a.68.68 0 1 0 0 1.359h7.698a.68.68 0 1 0 0-1.359m-3.17-2.445h-4.528a.68.68 0 1 0 0 1.359h4.528a.68.68 0 1 0 0-1.359' />
        </svg>
      );
    });

    export { SiPremid as default, defaultColor };
  