
    import * as React from 'react';

    import { IconType } from '../types';

    type SiTresoritProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#00A9E2';

    const SiTresorit: IconType = React.forwardRef<SVGSVGElement, SiTresoritProps>(function SiTresorit({title = 'Tresorit', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M12 0 1.636 6v12L12 24l10.364-6V6zM3.818 7.258 12 2.521l3.574 2.069-11.756 6.753zm16.364 9.484L12 21.48 3.82 16.742V13.86l13.938-8.006 2.425 1.404z' />
        </svg>
      );
    });

    export { SiTresorit as default, defaultColor };
  