
    import * as React from 'react';

    import { IconType } from '../types';

    type SiVoelknerProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#94C125';

    const SiVoelkner: IconType = React.forwardRef<SVGSVGElement, SiVoelknerProps>(function SiVoelkner({title = 'voelkner', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M19.4 3.502C18.093 8.84 15.018 16.05 11.964 16.05S5.841 8.827 4.552 3.502H0c.229 1.007 1.121 4.707 2.597 8.122 2.543 5.89 5.695 8.876 9.367 8.876s6.828-2.991 9.385-8.893C22.806 8.247 23.737 4.592 24 3.5h-4.6z' />
        </svg>
      );
    });

    export { SiVoelkner as default, defaultColor };
  